Crate min_html
min_
html
0.18.4
All Items
Crate Items
Structs
Functions
Crate
min_
html
Structs

Cfg
Configuration settings that can be adjusted and passed to a minification function to change the minification approach.
Functions

canonicalise
minify
Minifies UTF-8 HTML code, represented as an array of bytes.